@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Array;
-$List::Objects::WithUtils::Role::Array::VERSION = '2.021001';
+$List::Objects::WithUtils::Role::Array::VERSION = '2.021002';
 use strictures 1;
 
 use Carp            ();
@@ -429,11 +429,11 @@ sub natatime {
   my @list  = @{ $_[0] };
   my $count = $_[1];
   my $itr = sub { CORE::splice @list, 0, $count };
-  if ($_[2]) {
+  if (defined $_[2]) {
     while (my @nxt = $itr->()) { $_[2]->(@nxt) }
-  } else { 
-    return $itr
+    return
   }
+  $itr
 }
 
 sub rotator {
@@ -557,7 +557,10 @@ sub rotate {
   }
 }
 
-sub rotate_in_place { $_[0] = $_[0]->rotate(@_[1 .. $#_]) }
+sub rotate_in_place {
+  $_[0] = Scalar::Util::blessed $_[0] ?
+    $_[0]->rotate(@_[1 .. $#_]) : rotate(@_)
+}
 
 sub items_after {
   my ($started, $lag);
@@ -1342,8 +1345,8 @@ Returns the original array object.
 Returns a new array object consisting of the list sorted by the given
 subroutine.
 
-Prior to version 2.18.1, C<$_[0]> and C<$_[1]> must be used in place of C<$a>
-and C<$b>, respectively.
+Prior to version 2.18.1, positional arguments (C<$_[0]> and C<$_[1]>) must be
+used in place of C<$a> and C<$b>, respectively. 
 
 =head3 sort_by
 
